@@ -10,9 +10,6 @@ import exceptions
 import interface
 import util
 
-
-# Parsing (import error?)
-
 import xml.etree.ElementTree as ET
 
 
@@ -52,6 +49,8 @@ def parse_bucket_listing(data):
 
     return r
 
+
+
 class S3Storage(interface.CloudStorage):
     def __init__(self, url, credentials):
         interface.CloudStorage.__init__(self, url.geturl())
@@ -92,7 +91,8 @@ class S3Storage(interface.CloudStorage):
         prepared = request.prepare()
         verb = prepared.method
         content_type = prepared.headers.get('Content-Type', '')
-        md5 = util.md5(prepared.body)
+        md5 = ''  # MD5 is optional and caused errors, not using it for now
+        # md5 = util.md5(prepared.body)
         date = prepared.headers.get('Date', util.rfc1123_date())
         canonicalized_resource = '/' + self.bucket + urlparse(request.url).path
 
@@ -105,6 +105,7 @@ class S3Storage(interface.CloudStorage):
                   '{content_type}\n' \
                   '{date}\n' \
                   '{canonicalized_headers}{canonicalized_resource}'.format(**locals())
+        print to_sign
         signature = b64encode(util.hmac_sha1(key=self.secret_access_key, to_sign=to_sign))
         prepared.headers['Authorization'] = 'AWS {0}:{1}'.format(self.key_id, signature)
         return prepared
@@ -161,7 +162,7 @@ class S3Storage(interface.CloudStorage):
     def delete(self, obj):
         r = self.request('DELETE', '/' + obj)
 
-        if r.status_code == 200:
+        if r.status_code == 204:
             return True
         elif r.status_code == 404:
             return False
@@ -229,4 +230,4 @@ class S3Storage(interface.CloudStorage):
         elif r.status_code == 404:
             return False
         else:
-            raise exceptions.LuggageException.from_respone(r)
+            raise exceptions.LuggageException.from_respone(r)
\ No newline at end of file
